==> gnome-vfs-2.11.92.tar.bz2: gnome-vfs-2.11.92/libgnomevfs/gnome-vfs-private.h <==
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */

/* gnome-vfs-private.h - Private header file for the GNOME Virtual
   File System.

   Copyright (C) 1999 Free Software Foundation

   The Gnome Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   The Gnome Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with the Gnome Library; see the file COPYING.LIB.  If not,
   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.

   Author: Ettore Perazzoli <ettore@gnu.org> */

#ifndef GNOME_VFS_PRIVATE_H
#define GNOME_VFS_PRIVATE_H

#include <glib.h>
#include <libgnomevfs/gnome-vfs-volume-monitor.h>

#define GNOME_VFS_MODULE_SUBDIR  "gnome-vfs-2.0/modules"

typedef void (*GnomeVFSDaemonForceProbeCallback) (GnomeVFSVolumeMonitor *volume_monitor);

void gnome_vfs_set_is_daemon (GType volume_monitor_type,
			      GnomeVFSDaemonForceProbeCallback force_probe);
gboolean gnome_vfs_get_is_daemon (void);

GType _gnome_vfs_get_daemon_volume_monitor_type (void);
GnomeVFSDaemonForceProbeCallback _gnome_vfs_get_daemon_force_probe_callback (void);


#endif /* GNOME_VFS_PRIVATE_H */

==> gnome-vfs-2.20.0.tar.bz2: gnome-vfs-2.20.0/libgnomevfs/gnome-vfs-private.h <==
/* -*- Mode: C; indent-tabs-mode: t; c-basic-offset: 8; tab-width: 8 -*- */

/* gnome-vfs-private.h - Private header file for the GNOME Virtual
   File System.

   Copyright (C) 1999 Free Software Foundation

   The Gnome Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public License as
   published by the Free Software Foundation; either version 2 of the
   License, or (at your option) any later version.

   The Gnome Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Library General Public License for more details.

   You should have received a copy of the GNU Library General Public
   License along with the Gnome Library; see the file COPYING.LIB.  If not,
   write to the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.

   Author: Ettore Perazzoli <ettore@gnu.org> */

#ifndef GNOME_VFS_PRIVATE_H
#define GNOME_VFS_PRIVATE_H

#include <glib.h>
#include <libgnomevfs/gnome-vfs-volume-monitor.h>

#define GNOME_VFS_MODULE_SUBDIR  "gnome-vfs-2.0/modules"

typedef void (*GnomeVFSDaemonForceProbeCallback) (GnomeVFSVolumeMonitor *volume_monitor);

void gnome_vfs_set_is_daemon (GType volume_monitor_type,
			      GnomeVFSDaemonForceProbeCallback force_probe);
gboolean gnome_vfs_get_is_daemon (void);

GType gnome_vfs_get_daemon_volume_monitor_type (void);
GnomeVFSDaemonForceProbeCallback _gnome_vfs_get_daemon_force_probe_callback (void);


#endif /* GNOME_VFS_PRIVATE_H */
